@@ -69,18 +69,11 @@ def LoadPresetNames():
 
     for i in range(0, 4):
         try:
+            print i
             tmp=PresetNames.get('main', 'preset'+str(i+1))
             data.preset_names[i] = tmp.decode("utf-8")
         except:
-#            name=_("Preset")
-#            name=unicode(name)
-#            name=name.decode("utf-8")
-##Todo: Get unicode problem working
-            name="Preset"
-            data.preset_names[i]=name+" "+str(i+1)
-            PresetNames.set('main', 'preset'+str(i+1), data.preset_names[i])
-
-
+             data.preset_names[i]=""
 
 
 ###########################################################################
@@ -94,7 +87,9 @@ def WritePresetNames():
     print "Write preset names"
 
     for i in range(0, 3):
-        PresetNames.set('main', 'Preset'+str(i+1),  str(data.preset_names[i].encode( "utf-8" )))
+        if(data.preset_names[i]!=""): name=str(data.preset_names[i].encode( "utf-8" ))
+        else: name=""
+        PresetNames.set('main', 'Preset'+str(i+1),  name)
 
 
     f=data.configFolder+data.PresetNamesFile
@@ -139,8 +134,6 @@ def LoadConfig():
         pass
 
 
-
-
     data.Sampling_interval = Config_Load_Int('main', 'sampling', data.Sampling_interval)
     data.Sample_smoothing = Config_Load_Int('main', 'Sample_smoothing', data.Sample_smoothing)
     data.Value_smoothing = Config_Load_Int('main', 'Value_smoothing', data.Value_smoothing)
