@@ -516,32 +516,52 @@ def DrawStatistic(self, QtGui, QtCore):
 
     paint.setPen(QtGui.QColor(data.GraphBackground))
 
+    paint.setFont(QtGui.QFont('Decorative', 12))
+
+    y=10
+    paint.setPen(QtGui.QColor("White"))
+    paint.drawText(0, y+11, str(records.arrStatData[0][3])+"%")
+    paint.drawText(42, y+11, strftime("%Hh %Mm ", time.gmtime(records.arrStatData[0][0])))
     if(records.arrStatData[0][3]>0): #Awake
-        gradient = QtGui.QLinearGradient(0, 20, 0, 30)
+        gradient = QtGui.QLinearGradient(0, y, 0, y+10)
         gradient.setColorAt(0, QtGui.QColor(data.Awake_Color))
         gradient.setColorAt(0.5, QtGui.QColor(data.Awake_ColorDark))
         gradient.setColorAt(1, QtGui.QColor(data.Awake_Color))
         paint.setBrush(QtGui.QBrush(gradient))
         paint.setPen(QtGui.QColor(data.Awake_Color))
-        paint.drawRect(0, 20, records.arrStatData[0][3], 10)
+        paint.drawRect(120, y, records.arrStatData[0][3], 10)
 
+    y=30
+    paint.setPen(QtGui.QColor("White"))
+    paint.drawText(0, y+11, str(records.arrStatData[1][3])+"%")
+    paint.drawText(42, y+11, strftime("%Hh %Mm ", time.gmtime(records.arrStatData[1][0])))
     if(records.arrStatData[1][3]>0): #Light Sleep
-        gradient = QtGui.QLinearGradient(0, 35, 0, 45)
+        gradient = QtGui.QLinearGradient(0, y, 0, y+10)
         gradient.setColorAt(0, QtGui.QColor(data.Light_Sleep_Color))
         gradient.setColorAt(0.5, QtGui.QColor(data.Light_Sleep_ColorDark))
         gradient.setColorAt(1, QtGui.QColor(data.Light_Sleep_Color))
         paint.setBrush(QtGui.QBrush(gradient))
         paint.setPen(QtGui.QColor(data.Light_Sleep_Color))
-        paint.drawRect(0, 35, records.arrStatData[1][3], 10)
+        paint.drawRect(120, y, records.arrStatData[1][3], 10)
 
+    y=50
+    paint.setPen(QtGui.QColor("White"))
+    paint.drawText(0, y+11, str(records.arrStatData[2][3])+"%")
+    paint.drawText(42, y+11, strftime("%Hh %Mm ", time.gmtime(records.arrStatData[2][0])))
     if(records.arrStatData[2][3]>0): #deep sleep
-        gradient = QtGui.QLinearGradient(0, 50, 0, 60)
+        gradient = QtGui.QLinearGradient(0, y, 0, y+10)
         gradient.setColorAt(0, QtGui.QColor(data.Deep_Sleep_Color))
         gradient.setColorAt(0.5, QtGui.QColor(data.Deep_Sleep_ColorDark))
         gradient.setColorAt(1, QtGui.QColor(data.Deep_Sleep_Color))
         paint.setBrush(QtGui.QBrush(gradient))
         paint.setPen(QtGui.QColor(data.Deep_Sleep_Color))
-        paint.drawRect(0, 50, records.arrStatData[2][3], 10)
+        paint.drawRect(120, y, records.arrStatData[2][3], 10)
+
+
+
+
+
+
 
     paint.end()
 
